==> ZenTaoPMS.max2.0.rc1.php7.1.zip: zentaopms/module/upgrade/ext/lang/de/bizext.php <==
<?php
$lang->upgrade->fromVersions['15_0_rc2'] = '15.0.rc2';

$lang->upgrade->fromVersions['pro1_0']       = 'Pro1.0';
$lang->upgrade->fromVersions['pro1_1']       = 'Pro1.1';
$lang->upgrade->fromVersions['pro1_1_1']     = 'Pro1.1.1';
$lang->upgrade->fromVersions['pro1_2']       = 'Pro1.2';
$lang->upgrade->fromVersions['pro1_3']       = 'Pro1.3';
$lang->upgrade->fromVersions['pro2_0']       = 'Pro2.0';
$lang->upgrade->fromVersions['pro2_0_1']     = 'Pro2.0.1';
$lang->upgrade->fromVersions['pro2_1']       = 'Pro2.1';
$lang->upgrade->fromVersions['pro2_2_beta']  = 'Pro2.2.beta';
$lang->upgrade->fromVersions['pro2_3_beta']  = 'Pro2.3.beta';
$lang->upgrade->fromVersions['pro3_0_beta1'] = 'Pro3.0.beta1';
$lang->upgrade->fromVersions['pro3_0']       = 'Pro3.0';
$lang->upgrade->fromVersions['pro3_1']       = 'Pro3.1';
$lang->upgrade->fromVersions['pro3_2']       = 'Pro3.2';
$lang->upgrade->fromVersions['pro3_2_1']     = 'Pro3.2.1';
$lang->upgrade->fromVersions['pro3_3']       = 'Pro3.3';
$lang->upgrade->fromVersions['pro4_0_beta1'] = 'Pro4.0.beta1';
$lang->upgrade->fromVersions['pro4_0']       = 'Pro4.0';
$lang->upgrade->fromVersions['pro4_1_beta']  = 'Pro4.1.beta';
$lang->upgrade->fromVersions['pro4_2']       = 'Pro4.2';
$lang->upgrade->fromVersions['pro4_3']       = 'Pro4.3';
$lang->upgrade->fromVersions['pro4_4']       = 'Pro4.4';
$lang->upgrade->fromVersions['pro4_5']       = 'Pro4.5';
$lang->upgrade->fromVersions['pro4_6']       = 'Pro4.6';
$lang->upgrade->fromVersions['pro4_7']       = 'Pro4.7';
$lang->upgrade->fromVersions['pro4_7_1']     = 'Pro4.7.1';
$lang->upgrade->fromVersions['pro5_0']       = 'Pro5.0';
$lang->upgrade->fromVersions['pro5_0_1']     = 'Pro5.0.1';
$lang->upgrade->fromVersions['pro5_1']       = 'Pro5.1';
$lang->upgrade->fromVersions['pro5_1_3']     = 'Pro5.1.3';
$lang->upgrade->fromVersions['pro5_2']       = 'Pro5.2';
$lang->upgrade->fromVersions['pro5_2_1']     = 'Pro5.2.1';
$lang->upgrade->fromVersions['pro5_3']       = 'Pro5.3';
$lang->upgrade->fromVersions['pro5_3_1']     = 'Pro5.3.1';
$lang->upgrade->fromVersions['pro5_3_2']     = 'Pro5.3.2';
$lang->upgrade->fromVersions['pro5_3_3']     = 'Pro5.3.3';
$lang->upgrade->fromVersions['pro5_4']       = 'Pro5.4';
$lang->upgrade->fromVersions['pro5_4_1']     = 'Pro5.4.1';
$lang->upgrade->fromVersions['pro5_5']       = 'Pro5.5';
$lang->upgrade->fromVersions['pro5_5_1']     = 'Pro5.5.1';
$lang->upgrade->fromVersions['pro6_0_beta']  = 'pro6.0.beta';
$lang->upgrade->fromVersions['pro6_0']       = 'pro6.0';
$lang->upgrade->fromVersions['pro6_0_1']     = 'pro6.0.1';
$lang->upgrade->fromVersions['pro6_1']       = 'pro6.1';
$lang->upgrade->fromVersions['pro6_2']       = 'pro6.2';
$lang->upgrade->fromVersions['pro6_3']       = 'pro6.3';
$lang->upgrade->fromVersions['pro6_3_1']     = 'pro6.3.1';
$lang->upgrade->fromVersions['pro6_4']       = 'pro6.4';
$lang->upgrade->fromVersions['pro6_5']       = 'pro6.5';
$lang->upgrade->fromVersions['pro6_5_1']     = 'pro6.5.1';
$lang->upgrade->fromVersions['pro6_6']       = 'pro6.6';
$lang->upgrade->fromVersions['pro6_6_1']     = 'pro6.6.1';
$lang->upgrade->fromVersions['pro6_7']       = 'pro6.7';
$lang->upgrade->fromVersions['pro6_7_1']     = 'pro6.7.1';
$lang->upgrade->fromVersions['pro6_7_2']     = 'pro6.7.2';
$lang->upgrade->fromVersions['pro6_7_3']     = 'pro6.7.3';
$lang->upgrade->fromVersions['pro7_0_beta']  = 'pro7.0.beta';
$lang->upgrade->fromVersions['pro7_1']       = 'pro7.1';
$lang->upgrade->fromVersions['pro7_2']       = 'pro7.2';
$lang->upgrade->fromVersions['pro7_3']       = 'pro7.3';
$lang->upgrade->fromVersions['pro7_4']       = 'pro7.4';
$lang->upgrade->fromVersions['pro7_5']       = 'pro7.5';
$lang->upgrade->fromVersions['pro7_5_1']     = 'pro7.5.1';
$lang->upgrade->fromVersions['pro8_0']       = 'pro8.0';
$lang->upgrade->fromVersions['pro8_1']       = 'pro8.1';
$lang->upgrade->fromVersions['pro8_2']       = 'pro8.2';
$lang->upgrade->fromVersions['pro8_3']       = 'pro8.3';
$lang->upgrade->fromVersions['pro8_3_1']     = 'pro8.3.1';
$lang->upgrade->fromVersions['pro8_4']       = 'pro8.4';
$lang->upgrade->fromVersions['pro8_5']       = 'pro8.5';
$lang->upgrade->fromVersions['pro8_5_1']     = 'pro8.5.1';
$lang->upgrade->fromVersions['pro8_5_2']     = 'pro8.5.2';
$lang->upgrade->fromVersions['pro8_5_3']     = 'pro8.5.3';
$lang->upgrade->fromVersions['pro8_6']       = 'pro8.6';
$lang->upgrade->fromVersions['pro8_7']       = 'pro8.7';
$lang->upgrade->fromVersions['pro8_7_1']     = 'pro8.7.1';
$lang->upgrade->fromVersions['pro8_8']       = 'pro8.8';
$lang->upgrade->fromVersions['pro8_8_1']     = 'pro8.8.1';
$lang->upgrade->fromVersions['pro8_8_2']     = 'pro8.8.2';
$lang->upgrade->fromVersions['pro8_8_3']     = 'pro8.8.3';
$lang->upgrade->fromVersions['pro8_9']       = 'pro8.9';
$lang->upgrade->fromVersions['pro8_9_1']     = 'pro8.9.1';
$lang->upgrade->fromVersions['pro8_9_2']     = 'pro8.9.2';
$lang->upgrade->fromVersions['pro8_9_3']     = 'pro8.9.3';
$lang->upgrade->fromVersions['pro8_9_4']     = 'pro8.9.4';
$lang->upgrade->fromVersions['pro9_0']       = 'pro9.0';
$lang->upgrade->fromVersions['pro9_0_1']     = 'pro9.0.1';
$lang->upgrade->fromVersions['pro9_0_2']     = 'pro9.0.2';
$lang->upgrade->fromVersions['pro9_0_3']     = 'pro9.0.3';

==> ZenTaoPMS.max2.2.php7.0.zip: zentaopms/module/upgrade/ext/lang/de/bizext.php <==
<?php
$lang->upgrade->fromVersions['15_5'] = '15.5';

$lang->upgrade->fromVersions['pro1_0']       = 'Pro1.0';
$lang->upgrade->fromVersions['pro1_1']       = 'Pro1.1';
$lang->upgrade->fromVersions['pro1_1_1']     = 'Pro1.1.1';
$lang->upgrade->fromVersions['pro1_2']       = 'Pro1.2';
$lang->upgrade->fromVersions['pro1_3']       = 'Pro1.3';
$lang->upgrade->fromVersions['pro2_0']       = 'Pro2.0';
$lang->upgrade->fromVersions['pro2_0_1']     = 'Pro2.0.1';
$lang->upgrade->fromVersions['pro2_1']       = 'Pro2.1';
$lang->upgrade->fromVersions['pro2_2_beta']  = 'Pro2.2.beta';
$lang->upgrade->fromVersions['pro2_3_beta']  = 'Pro2.3.beta';
$lang->upgrade->fromVersions['pro3_0_beta1'] = 'Pro3.0.beta1';
$lang->upgrade->fromVersions['pro3_0']       = 'Pro3.0';
$lang->upgrade->fromVersions['pro3_1']       = 'Pro3.1';
$lang->upgrade->fromVersions['pro3_2']       = 'Pro3.2';
$lang->upgrade->fromVersions['pro3_2_1']     = 'Pro3.2.1';
$lang->upgrade->fromVersions['pro3_3']       = 'Pro3.3';
$lang->upgrade->fromVersions['pro4_0_beta1'] = 'Pro4.0.beta1';
$lang->upgrade->fromVersions['pro4_0']       = 'Pro4.0';
$lang->upgrade->fromVersions['pro4_1_beta']  = 'Pro4.1.beta';
$lang->upgrade->fromVersions['pro4_2']       = 'Pro4.2';
$lang->upgrade->fromVersions['pro4_3']       = 'Pro4.3';
$lang->upgrade->fromVersions['pro4_4']       = 'Pro4.4';
$lang->upgrade->fromVersions['pro4_5']       = 'Pro4.5';
$lang->upgrade->fromVersions['pro4_6']       = 'Pro4.6';
$lang->upgrade->fromVersions['pro4_7']       = 'Pro4.7';
$lang->upgrade->fromVersions['pro4_7_1']     = 'Pro4.7.1';
$lang->upgrade->fromVersions['pro5_0']       = 'Pro5.0';
$lang->upgrade->fromVersions['pro5_0_1']     = 'Pro5.0.1';
$lang->upgrade->fromVersions['pro5_1']       = 'Pro5.1';
$lang->upgrade->fromVersions['pro5_1_3']     = 'Pro5.1.3';
$lang->upgrade->fromVersions['pro5_2']       = 'Pro5.2';
$lang->upgrade->fromVersions['pro5_2_1']     = 'Pro5.2.1';
$lang->upgrade->fromVersions['pro5_3']       = 'Pro5.3';
$lang->upgrade->fromVersions['pro5_3_1']     = 'Pro5.3.1';
$lang->upgrade->fromVersions['pro5_3_2']     = 'Pro5.3.2';
$lang->upgrade->fromVersions['pro5_3_3']     = 'Pro5.3.3';
$lang->upgrade->fromVersions['pro5_4']       = 'Pro5.4';
$lang->upgrade->fromVersions['pro5_4_1']     = 'Pro5.4.1';
$lang->upgrade->fromVersions['pro5_5']       = 'Pro5.5';
$lang->upgrade->fromVersions['pro5_5_1']     = 'Pro5.5.1';
$lang->upgrade->fromVersions['pro6_0_beta']  = 'pro6.0.beta';
$lang->upgrade->fromVersions['pro6_0']       = 'pro6.0';
$lang->upgrade->fromVersions['pro6_0_1']     = 'pro6.0.1';
$lang->upgrade->fromVersions['pro6_1']       = 'pro6.1';
$lang->upgrade->fromVersions['pro6_2']       = 'pro6.2';
$lang->upgrade->fromVersions['pro6_3']       = 'pro6.3';
$lang->upgrade->fromVersions['pro6_3_1']     = 'pro6.3.1';
$lang->upgrade->fromVersions['pro6_4']       = 'pro6.4';
$lang->upgrade->fromVersions['pro6_5']       = 'pro6.5';
$lang->upgrade->fromVersions['pro6_5_1']     = 'pro6.5.1';
$lang->upgrade->fromVersions['pro6_6']       = 'pro6.6';
$lang->upgrade->fromVersions['pro6_6_1']     = 'pro6.6.1';
$lang->upgrade->fromVersions['pro6_7']       = 'pro6.7';
$lang->upgrade->fromVersions['pro6_7_1']     = 'pro6.7.1';
$lang->upgrade->fromVersions['pro6_7_2']     = 'pro6.7.2';
$lang->upgrade->fromVersions['pro6_7_3']     = 'pro6.7.3';
$lang->upgrade->fromVersions['pro7_0_beta']  = 'pro7.0.beta';
$lang->upgrade->fromVersions['pro7_1']       = 'pro7.1';
$lang->upgrade->fromVersions['pro7_2']       = 'pro7.2';
$lang->upgrade->fromVersions['pro7_3']       = 'pro7.3';
$lang->upgrade->fromVersions['pro7_4']       = 'pro7.4';
$lang->upgrade->fromVersions['pro7_5']       = 'pro7.5';
$lang->upgrade->fromVersions['pro7_5_1']     = 'pro7.5.1';
$lang->upgrade->fromVersions['pro8_0']       = 'pro8.0';
$lang->upgrade->fromVersions['pro8_1']       = 'pro8.1';
$lang->upgrade->fromVersions['pro8_2']       = 'pro8.2';
$lang->upgrade->fromVersions['pro8_3']       = 'pro8.3';
$lang->upgrade->fromVersions['pro8_3_1']     = 'pro8.3.1';
$lang->upgrade->fromVersions['pro8_4']       = 'pro8.4';
$lang->upgrade->fromVersions['pro8_5']       = 'pro8.5';
$lang->upgrade->fromVersions['pro8_5_1']     = 'pro8.5.1';
$lang->upgrade->fromVersions['pro8_5_2']     = 'pro8.5.2';
$lang->upgrade->fromVersions['pro8_5_3']     = 'pro8.5.3';
$lang->upgrade->fromVersions['pro8_6']       = 'pro8.6';
$lang->upgrade->fromVersions['pro8_7']       = 'pro8.7';
$lang->upgrade->fromVersions['pro8_7_1']     = 'pro8.7.1';
$lang->upgrade->fromVersions['pro8_8']       = 'pro8.8';
$lang->upgrade->fromVersions['pro8_8_1']     = 'pro8.8.1';
$lang->upgrade->fromVersions['pro8_8_2']     = 'pro8.8.2';
$lang->upgrade->fromVersions['pro8_8_3']     = 'pro8.8.3';
$lang->upgrade->fromVersions['pro8_9']       = 'pro8.9';
$lang->upgrade->fromVersions['pro8_9_1']     = 'pro8.9.1';
$lang->upgrade->fromVersions['pro8_9_2']     = 'pro8.9.2';
$lang->upgrade->fromVersions['pro8_9_3']     = 'pro8.9.3';
$lang->upgrade->fromVersions['pro8_9_4']     = 'pro8.9.4';
$lang->upgrade->fromVersions['pro9_0']       = 'pro9.0';
$lang->upgrade->fromVersions['pro9_0_1']     = 'pro9.0.1';
$lang->upgrade->fromVersions['pro9_0_2']     = 'pro9.0.2';
$lang->upgrade->fromVersions['pro9_0_3']     = 'pro9.0.3';
$lang->upgrade->fromVersions['pro10_0_rc1']  = 'pro10.0.rc1';
$lang->upgrade->fromVersions['pro10_0']      = 'pro10.0';
$lang->upgrade->fromVersions['pro10_0_1']    = 'pro10.0.1';
$lang->upgrade->fromVersions['pro10_0_2']    = 'pro10.0.2';
$lang->upgrade->fromVersions['pro10_1']      = 'pro10.1';
